@@ -396,7 +396,7 @@ impl Value
                 output
             }
             Value::Packed(p) => p.encode(),
-            Value::Unknown(..) => return None,
+            Value::Unknown(u) => u.encode(),
             Value::Incomplete(_, bytes) => BytesMut::from(bytes.as_ref()),
         };
 
@@ -622,6 +622,10 @@ impl MessageInfo
 impl MessageValue
 {
     /// Encodes a message value into protobuf wire format.
+    ///
+    /// Will **panic** if the message defined by the `MessageRef` does not exist in this context.
+    /// Such panic means the `MessageRef` came from a different context. The panic is not
+    /// guaranteed, as a message with an equal `MessageRef` may exist in multiple contexts.
     pub fn encode(&self, ctx: &Context) -> bytes::BytesMut
     {
         self.fields
@@ -638,6 +642,25 @@ impl MessageValue
     }
 }
 
+impl UnknownValue
+{
+    /// Encodes a message value into protobuf wire format.
+    fn encode(&self) -> bytes::BytesMut
+    {
+        match self {
+            UnknownValue::Varint(v) => v.into_unsigned_varint(),
+            UnknownValue::Fixed64(v) => BytesMut::from(v.to_le_bytes().as_ref()),
+            UnknownValue::VariableLength(b) => {
+                let mut output = b.len().into_unsigned_varint();
+                output.extend_from_slice(b);
+                output
+            }
+            UnknownValue::Fixed32(v) => BytesMut::from(v.to_le_bytes().as_ref()),
+            UnknownValue::Invalid(_, v) => BytesMut::from(v.as_ref()),
+        }
+    }
+}
+
 trait FromUnsignedVarint: Sized
 {
     fn from_unsigned_varint(data: &mut &[u8]) -> Option<Self>;
